@@ -5,6 +5,8 @@ from .log_helper import LogHelper
 from .common import StaticVariable
 
 Log = LogHelper()
+
+
 # param_conf = StaticVariable().getParam('param_conf')
 
 
@@ -39,6 +41,7 @@ class ParamReg:
 
     Card_No = r"^[1-9]\d{5}(18|19|([23]\d))\d{2}((0[1-9])|(10|11|12))(([0-2][1-9])|10|20|30|31)\d{3}[0-9Xx]$"  # 身份证号
 
+
 # 0非必填 1必填
 class Param:
     def __init__(self, request):
@@ -79,6 +82,8 @@ class Param:
                     return param
 
     def Response(self, rtn_code, rtnDesc="", Body=None):
+        if not isinstance(rtnDesc, str):
+            rtnDesc = '-'.join([str(v) for v in rtnDesc.args])
         rtnObj = rtn_code.value[0]
         rtnObj["rtnDesc"] = rtnDesc
         if Body is not None:
